@@ -72,7 +72,11 @@ void do_mail (CWidget *edit);
 
 int start_width = 80;
 int start_height = 30;
+#ifndef NEXT_LOOK
 char *option_look = "gtk";
+#else
+char *option_look = "next";
+#endif
 
 /* error handler */
 #ifdef DEBUG
@@ -208,12 +212,12 @@ void get_next_hint_message (void)
 /* The following are hints that go on the title bar: eg "Cooledit - Hint: Undo key-for-key with Ctrl-Backspace" */
 	gettext_noop("To drag and drop, highlight text, then click and drag from within the selection"),
 	gettext_noop("Dragging with the right mouse button will move text"),
-	gettext_noop("Goto http://www.obsidian.co.za/ - Obsidian Systems - Linux IT services"),
+	gettext_noop("Goto http://www.icon.co.za/~psheer - Paul Sheer Consulting IT Services"),
 	gettext_noop("Dragging with the left mouse button will copy text"),
 	gettext_noop("Use Shift-Insert to copy text from other applications"),
 	gettext_noop("Use Alt-Insert to bring up a history of selected text"),
 	gettext_noop("Function keys F11-F20 mean Shift with a function key F1-F10"),
-	gettext_noop("Subscribe to or email our mailing list: cooledit@mail.obsidian.co.za"),
+	gettext_noop("Do not email the author with generic questions, goto your local LUG instead"),
 	gettext_noop("See how to do regular expression substring replacements in the man page"),
 	gettext_noop("Use Shift-Up/Down in input widgets to get a history of inputs"),
 	gettext_noop("Run frequently used apps from a hot key: see the Scripts menu"),
@@ -224,12 +228,12 @@ void get_next_hint_message (void)
 	gettext_noop("Undo key-for-key with Ctrl-Backspace"),
 	gettext_noop("Drag function prototypes and other info from the man page browser"),
 	gettext_noop("Double click on words in the man page browser to search for new man pages"),
-	gettext_noop("Goto http://www.obsidian.co.za/ - Obsidian Systems - Linux IT services"),
+	gettext_noop("Goto http://www.icon.co.za/~psheer - Paul Sheer Consulting IT Services"),
 	gettext_noop("Search for [Options] in  ~/.cedit/.cooledit.ini  and change settings"),
 	gettext_noop("Edit the example Scripts to see how to create your own"),
 	gettext_noop("Double click on gcc error messages after running Make or Cc"),
 	gettext_noop("Turn off these messages from the Options menu: 'Hint time...' = 0"),
-	gettext_noop("Email  cooledit@mail.obsidian.co.za  with questions, comments or suggestions"),
+	gettext_noop("Do not email the author with generic questions, goto your local LUG instead"),
 	gettext_noop("See how to do regular expression substring replacements in the man page"),
 	gettext_noop("See cooledit.1 for a list of the many extended editing/movement keys"),
 	gettext_noop("Compose international characters with Right-Control"),
@@ -240,7 +244,7 @@ void get_next_hint_message (void)
 	gettext_noop("Read all these hint messages in editor/cooledit.c in the source distribution"),
 	gettext_noop("See the file INTERNATIONAL for composing international characters"),
 	gettext_noop("Edit/move at high speed with the many Ctrl/Meta-Arrow combinations"),
-	gettext_noop("Goto http://www.obsidian.co.za/ - Obsidian Systems - Linux IT services"),
+	gettext_noop("Goto http://www.icon.co.za/~psheer - Paul Sheer Consulting IT Services"),
 	gettext_noop("Use drag-and-drop to and from input widgets"),
 	gettext_noop("Open a file by dragging its name from the 'File browser' onto the background"),
 	gettext_noop("Use Shift-Ins to paste into input widgets"),
@@ -260,7 +264,7 @@ void get_next_hint_message (void)
 	gettext_noop("Try your hand at adding new Cooledit features with Python"),
 	gettext_noop("Mark locations in files with the book mark commands in the Edit menu"),
 	gettext_noop("Debug programs with Meta-F5"),
-	gettext_noop("Goto http://www.obsidian.co.za/ - Obsidian Systems - Linux IT services"),
+	gettext_noop("Goto http://www.icon.co.za/~psheer - Paul Sheer Consulting IT Services"),
 	gettext_noop("Execute explicit debugger commands with Meta-F1"),
 	gettext_noop("Turn off spell checking from the Options menu"),
 	gettext_noop("File files containing regular expressions with Ctrl-Meta-F"),
@@ -274,7 +278,7 @@ void get_next_hint_message (void)
 	gettext_noop("Enable \"Smooth scrolling\" option if you have a fast graphics card"),
 	gettext_noop("Start internal XTerms with \"Terminal\" in the command menu"),
 	gettext_noop("Use the coolproject command to start projects"),
-	gettext_noop("Goto http://www.obsidian.co.za/ - Obsidian Systems - Linux IT services"),
+	gettext_noop("Goto http://www.icon.co.za/~psheer - Paul Sheer Consulting IT Services"),
 	gettext_noop("Display Unicode text - See FAQ"),
 	gettext_noop("All colours can have their RGB values set - see COLOURS in the man page"),
 	gettext_noop("Try different looks with the \"--look\" command line option"),
@@ -465,6 +469,7 @@ struct prog_options cooledit_options[] =
 {
     {' ', "", "", ARG_STRINGS, 0, 0, 0},
     {0, "-bg", "--background-color", ARG_STRING, &option_background_color, 0, 0},
+    {0, "", "--mad", ARG_IGNORE, 0, 0, 0},
 #ifdef GUESS_VISUAL
     {0, "-vis", "--visual", ARG_STRING, &option_preferred_visual, 0, 0},
     {'C', "-cmap", "--own-colormap",  ARG_SET, 0, 0, &option_force_own_colormap},
@@ -703,8 +708,7 @@ int goto_error (char *message, int raise_wm_window)
     if (new_file) {
 	if (!new_file_callback (new_file)) {
 	    edit_move_to_line_easy (edit[current_edit]->editor, l);
-	    if (raise_wm_window)
-		CRaiseWMWindow ("cooledit");
+	    CTryFocus (edit[current_edit], raise_wm_window);
 	    free (new_file);
 	    return 0;
 	}
@@ -714,11 +718,9 @@ int goto_error (char *message, int raise_wm_window)
 	current_edit = ed;
 	edit_move_to_line_easy (edit[current_edit]->editor, l);
 	edit[ed]->editor->force |= REDRAW_COMPLETELY;
-	CFocus (edit[ed]);
 	XRaiseWindow (CDisplay, edit[current_edit]->parentid);
+	CTryFocus (edit[current_edit], raise_wm_window);
 	CRaiseWindows ();
-	if (raise_wm_window)
-	    CRaiseWMWindow ("cooledit");
 	current_to_top ();
     }
     return 0;
@@ -1145,7 +1147,7 @@ int new_file_callback (char *full_file_name,...)
     }
     if (x) {
 	current_edit = 0;
-	CFocus (edit[current_edit]);
+	CTryFocus (edit[current_edit], 0);
 	result = 0;
     }
     if (d)
@@ -1384,37 +1386,6 @@ int read_config (void)
     DIR *dir;
     dir = opendir (catstrs (home_dir, EDIT_DIR, "/.t", 0));
     s = get_options_section (editor_options_file, "[Files]");
-    if (!dir && errno == ENOENT && !s) {
-	char *str;
-	char mail_command[256];
-	edit_about_cmd ();
-#ifdef HAVE_PYTHON
-#define HAVE_PYTHON_VERSION "p"
-#else
-#define HAVE_PYTHON_VERSION ""
-#endif
-	str = catstrs (_ (" \n" \
-		     " Cooledit will now mail the following message \n" \
-			  " to count the number of cooledit users: \n"), \
-		       " \n" \
-		       " >\n" \
-		       " > Cooledit-" VERSION HAVE_PYTHON_VERSION " automatic mail message: \n" \
-		       " > I am running on a " TARGET_MACHINE " \n" \
-		       " >\n", 0);
-#ifndef DISABLE_AUTO_MAIL
-	if (
-	       CQueryDialog (0, 0, 0, _ (" Mail me "), str, _ (" OK "), _ (" Cancel "), 0) == 0) {
-	    sprintf (mail_command, "/bin/sh -c 'echo \"Cooledit-" VERSION HAVE_PYTHON_VERSION " automatic mail message:\n" \
-		   "I am running on a " TARGET_MACHINE "\n.\n\004\n\" " \
-		     "| mail psheer@obsidian.co.za " \
-		     "> /dev/null'"
-		);
-	    CSystem (mail_command);
-	} else {
-	    exit (0);
-	}
-#endif
-    }
     if (!dir) {
 	mkdir (catstrs (home_dir, EDIT_DIR, 0), 0700);
 	mkdir (catstrs (home_dir, EDIT_DIR, "/.t", 0), 0700);
@@ -1963,7 +1934,7 @@ int main (int argc, char **argv)
     char *example_fonts[] =
     {
 	"-misc-fixed-bold-r-normal--13-120-75-75-c-80",
-	"-adobe-courier-medium-r-normal--13-120-75-75-m-60",
+	"-*-courier-medium-r-normal--13-120-75-75-m-60",
 	"-*-times-medium-r-*--14-*-*-*-p-*",
 	"-*-helvetica-bold-r-*--14-*-*-*-p-*",
 	"-*-charter-bold-r-*--14-*-*-*-p-*",
@@ -1973,9 +1944,16 @@ int main (int argc, char **argv)
 	"-*-*-bold-*-normal--10-100-75-75-c-80",
 	"-*-*-bold-r-normal--12-120-75-75-c-80",
 	"-*-*-bold-r-normal-*-15-*-*-*-c-*",
-	"-winfonts-arial-bold-r-*-*-45-*-*-*-*-*-iso8859-1"
+	"-winfonts-arial-bold-r-*-*-45-*-*-*-*-*-*-*"
     };
-    int n, qv;
+    int n;
+
+    if (argc > 1)
+	if (!strcmp (argv[1], "--mad"))
+	    option_debug_malloc++;
+    if (argc > 2)
+	if (!strcmp (argv[2], "--mad"))
+	    option_debug_malloc++;
 
     command_line_files = (char **) malloc ((argc + 1) * sizeof (char *));
     memset (command_line_files, 0, (argc + 1) * sizeof (char *));
@@ -2219,6 +2197,6 @@ int main (int argc, char **argv)
     global_callback = rxvt_event;
 
     main_loop ();
-    return r;
+    return 0;
 }
 
