@@ -549,8 +549,14 @@ static void debug_read_callback (int fd, fd_set * reading, fd_set * writing, fd_
 	break;
     case ACTION_VERSION:
 /* 4.18 doesn't seem to do next's properly */
-	if (!strstr ((char *) pool_start (d->pool), GDB_VERSION1) && !strstr ((char *) pool_start (d->pool), GDB_VERSION3))
-	    debug_error1 (d, catstrs (GDB_VERSION1 " or " GDB_VERSION3, _ (" expected. You seem to have a different debugger \n or version. If things don't work properly, this is why."), 0));
+	if (!strstr ((char *) pool_start (d->pool), GDB_VERSION1) && !strstr ((char *) pool_start (d->pool), GDB_VERSION3)) {
+	    static once = 1;
+	    if (once) {
+/* NLS: <version> or <version> expected. You seem... */
+		debug_error1 (d, catstrs (GDB_VERSION1 " ",  _ ("or"), " " GDB_VERSION3, _ (" expected. You seem to have a different debugger \n or version. If things don't work properly, this is why. \n This error will not display again in this session. "), 0));
+		once = 0;
+	    }
+	}
 	if (!d->pool)	/* process was terminated */
 	    break;
 	if (from_end ((char *) pool_start (d->pool), "no debugging symbols found", 6)) {
@@ -631,7 +637,8 @@ static void debug_read_callback (int fd, fd_set * reading, fd_set * writing, fd_
 	    }
 	}
 	if (!p) {
-	    debug_error1 (d, (char *) pool_start (d->pool));
+	    if (strlen ((char *) pool_start (d->pool)))
+		debug_error1 (d, (char *) pool_start (d->pool));
 	    if (!d->pool)
 		break;
 	    xdebug_flush_commands (d);
@@ -672,10 +679,18 @@ static void debug_read_callback (int fd, fd_set * reading, fd_set * writing, fd_
 	p = strstr ((char *) pool_start (d->pool), "Pid");
 	if (!p)
 	    p = strstr ((char *) pool_start (d->pool), "Thread");
+/* BUG FIX - gdb 5.0 says process instead of Pid */
+	if (!p)
+	    p = strstr ((char *) pool_start (d->pool), "process");
+/* end BUG FIX */
 	if (p) {
 	    p += strcspn (p, "0123456789");
 	    d->child = atoi (p);
 	}
+	if ((p = strstr ((char *) p, "LWP"))) {
+	    p += strcspn (p, "0123456789");
+	    d->child = atoi (p);
+	}
 	pool_free (d->pool);
 	d->pool = 0;
 	break;
