@@ -81,6 +81,8 @@ extern int option_smooth_scrolling;
 
 extern int option_new_window_ask_for_file;
 
+extern int option_never_raise_wm_windows;
+
 #ifdef HAVE_DND
 extern int option_dnd_version;
 #endif
@@ -147,6 +149,7 @@ static struct {
 	{"option_xor_cursor", &option_xor_cursor, gettext_noop(" Xor cursor "), TYPE_ON_OFF},
 	{"option_pull_down_window_list", &option_pull_down_window_list, gettext_noop(" Pull down 'Window' menu "), TYPE_ON_OFF},
 	{"option_find_bracket", &option_find_bracket, gettext_noop(" Highlight matching bracket "), TYPE_ON_OFF},
+	{"option_never_raise_wm_windows", &option_never_raise_wm_windows, gettext_noop(" Never Raise WM Windows "), TYPE_ON_OFF},
 	{"option_edit_right_extreme", &option_edit_right_extreme, 0, 0},
 	{"option_edit_left_extreme", &option_edit_left_extreme, 0, 0},
 	{"option_edit_top_extreme", &option_edit_top_extreme, 0, 0},
