@@ -516,8 +516,7 @@ static void shell_display_output (char *text, const char *heading, int (*select_
 	w->text = 0;
 	CRedrawTextbox (nm (i, "shelldisplaytext", "text", 0), text, 0);
 	CRedrawText (nm (i, "shelldisplaytext", "header", 0), heading);
-	CFocus (CIdent (nm (i, "shelldisplaytext", "text", 0)));
-	CRaiseWMWindow (nm (i, "shelldisplaytext", 0, 0));
+	CTryFocus (CIdent (nm (i, "shelldisplaytext", "text", 0)), 1);
     } else {
 	int x, y;
 	Window win;
