@@ -87,7 +87,7 @@ extern char *init_font;
 char *option_display = 0;
 
 /* font from the command line */
-char *option_font = "-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*";
+char *option_font = "-*-helvetica-medium-r-normal--*-120-*-*-*-*-*-*";
 
 /* config file */
 char *current_config_file = 0;
@@ -488,7 +488,6 @@ void close_all (CWidget * w)
     CShutdown ();
     free_all_lists ();
     catstrs_clean ();
-    mad_finalize (__FILE__, __LINE__);
     exit (0);
 }
 
