@@ -44,7 +44,7 @@ extern char *init_font;
 char *option_display = 0;
 
 /* font from the command line */
-char *option_font = "-*-helvetica-bold-r-*--14-*-*-*-p-*-iso8859-1";
+char *option_font = "-*-helvetica-bold-r-*--14-*-*-*-p-*-*-*";
 
 static int get_help = 0;
 static int get_version = 0;
