@@ -1100,9 +1100,9 @@ const char    **rxvtlib_init_resources (rxvtlib *o, int argc, const char *const
     for (i = 0; i < TOTAL_RS; i++)
 	o->rs[i] = NULL;
 
-    o->rs[Rs_name] = my_basename (argv[0]);
+    o->rs[Rs_name] = (char *) my_basename (argv[0]);
     if (cmd_argv != NULL && cmd_argv[0] != NULL)
-	o->rs[Rs_iconName] = o->rs[Rs_title] = my_basename (cmd_argv[0]);
+	o->rs[Rs_iconName] = o->rs[Rs_title] = (char *) my_basename (cmd_argv[0]);
 /*
  * Open display, get options/resources and create the window
  */
@@ -1228,7 +1228,7 @@ const char    **rxvtlib_init_resources (rxvtlib *o, int argc, const char *const
 #ifndef XTERM_REVERSE_VIDEO
 /* this is how we implement reverseVideo */
     if (o->Options & Opt_reverseVideo)
-	SWAP_IT (o->rs[Rs_color + Color_fg], o->rs[Rs_color + Color_bg], tmp);
+	SWAP_IT ((char *) o->rs[Rs_color + Color_fg], (char *) o->rs[Rs_color + Color_bg], (char *) tmp);
 #endif
 
 /* convenient aliases for setting fg/bg to colors */
