@@ -367,7 +367,7 @@ void            rxvtlib_usage (rxvtlib *o, int type)
 	    if (optList[i].desc != NULL)
 		fprintf (stderr, "    %s%s %-*s%s%s\n",
 			 (optList_isBool (i) ? "-/+" : "-"),
-			 optList[i].opt, (INDENT - strlen (optList[i].opt)
+			 optList[i].opt, (int) (INDENT - strlen (optList[i].opt)
 					  + (optList_isBool (i) ? 0 : 2)),
 			 (optList[i].arg ? optList[i].arg : ""),
 			 (optList_isBool (i) ? "turn on/off " : ""),
@@ -384,12 +384,12 @@ void            rxvtlib_usage (rxvtlib *o, int type)
 	    if (optList[i].kw != NULL)
 		fprintf (stderr, "    %s: %*s\n",
 			 optList[i].kw,
-			 (INDENT - strlen (optList[i].kw)),
+			 (int) (INDENT - strlen (optList[i].kw)),
 			 (optList_isBool (i) ? "boolean" : optList[i].arg));
 
 #ifdef KEYSYM_RESOURCE
 	fprintf (stderr, "    " "keysym.sym" ": %*s\n",
-		 (INDENT - strlen ("keysym.sym")), "keysym");
+		 (int) (INDENT - strlen ("keysym.sym")), "keysym");
 #endif
 	fprintf (stderr, "\n    -help to list options\n\n");
 	break;
@@ -459,7 +459,7 @@ void            rxvtlib_get_options (rxvtlib *o, int argc, const char *const *ar
 #ifdef DEBUG_RESOURCES
 		    fprintf (stderr, "\"%s\"\n", str);
 #endif
-		    *(&(o->rs[optList[entry].dp])) = str;
+		    *(&(o->rs[optList[entry].dp])) = (char *) str;
 
 		    /* special cases are handled in main.c:main() to allow
 		     * X resources to set these values before we settle for
@@ -481,7 +481,7 @@ void            rxvtlib_get_options (rxvtlib *o, int argc, const char *const *ar
 		    o->Options &= ~(optList[entry].flag);
 
 		if (optList[entry].dp != 1)
-		    *(&(o->rs[optList[entry].dp])) = flag;
+		    *(&(o->rs[optList[entry].dp])) = (char *) flag;
 	    }
 	} else
 #ifdef KEYSYM_RESOURCE
@@ -689,7 +689,7 @@ void            rxvtlib_get_xdefaults (rxvtlib *o, FILE * stream, const char *na
 			char           *p = MALLOC ((n + 1) * sizeof (char));
 
 			STRCPY (p, str);
-			*(&(o->rs[optList[entry].dp])) = p;
+			*(&(o->rs[optList[entry].dp])) = *(&(o->rs_free[optList[entry].dp])) = p;
 			if (optList_isBool (entry)) {
 			    s = my_strcasecmp (p, "TRUE") == 0
 				|| my_strcasecmp (p, "YES") == 0
