@@ -135,7 +135,7 @@ CWidget *CDrawSwitch (const char *identifier, Window parent, int x, int y, int o
 
     if (label) {
 	CWidget *t;
-#ifdef NEXT_LOOK_X
+#ifdef NEXT_LOOK
 	t = CDrawText (catstrs (identifier, ".label", 0), parent, x + l, y_label, "%s", label);
 #else
 	t = CDrawText (catstrs (identifier, ".label", 0), parent, x + l + WIDGET_SPACING, y_label, "%s", label);
