@@ -86,7 +86,7 @@ typedef union {
 	unsigned short style;
 	wchar_t ch;
     } c;
-    unsigned long style;
+    unsigned long _style;
 } cache_type;
 
 void edit_draw_proportional (void *data,
