@@ -597,6 +597,8 @@ static int CCheckTab (XEvent * xevent, CEvent * cwevent)
 	KeySym k;
 	CWidget *w;
 	k = CKeySym (xevent);
+	if (!k)
+	    return 0;
 	if (!is_focus_change_key (k, cwevent->command))
 	    return 0;
 
@@ -683,8 +685,12 @@ static long check_hotkey_callback (CWidget * w, long k)
 /* checks all widgets for a hotkey if alt is pressed */
 static int CCheckGlobalHotKey (XEvent * xevent, CEvent * cwevent)
 {
+    KeySym k;
+    k = CKeySym (xevent);
+    if (!k)
+	return 0;
     if (xevent->type == KeyPress && (xevent->xkey.state & MyAltMask) && !(xevent->xkey.state & ControlMask))
-	return for_all_widgets ((void *) check_hotkey_callback, (void *) CKeySym (xevent), 0);
+	return for_all_widgets ((void *) check_hotkey_callback, (void *) k, 0);
     return 0;
 }
 
@@ -1008,6 +1014,9 @@ int CIsIdle (void)
     return CIdle;
 }
 
+extern void _alarmhandler (void);
+extern int got_alarm;
+
 static int run_watches (void)
 {
     int r, n = 0, i, found_watch;
@@ -1038,6 +1047,9 @@ static int run_watches (void)
 	return 0;
 #endif	/* Norbert Nemec <nobbi@cheerful.com> */
     r = select (n + 1, &reading, &writing, &error, 0);
+    if (got_alarm)
+	_alarmhandler ();
+    childhandler_ ();
     if (r <= 0)
 	return 0;
     if (FD_ISSET (ConnectionNumber (CDisplay), &reading)) {
@@ -1146,10 +1158,12 @@ void CNextEvent (XEvent * xevent, CEvent * cwevent)
 	pop_all_regions (0);	/* just make sure not outstanding exposes */
     while (!pop_event (xevent)) {	/* first check our own events, if none of our own coming, _then_ we look at the server */
 	if (QLength (CDisplay)) {
+	    memset (xevent, 0, sizeof (XEvent));
 	    XNextEvent (CDisplay, xevent);
 	    next_event = 1;
 	    break;
 	} else if (run_watches ()) {
+	    memset (xevent, 0, sizeof (XEvent));
 	    XNextEvent (CDisplay, xevent);
 	    next_event = 1;
 	    break;
@@ -1267,9 +1281,11 @@ void CNextEvent (XEvent * xevent, CEvent * cwevent)
 	return;
 	break;
     case MotionNotify:
-	if (xevent->xbutton.button == Button2 && option_middle_button_pastes) {
+#if 0
+	if (xevent->xmotion.button == Button2 && option_middle_button_pastes) {
 	    break;
 	}
+#endif
 	if (xevent->xmotion.window == toolhint_window) {
 	    hide_toolhint ();
 	    x_toolhint = xevent->xmotion.x;
@@ -1360,11 +1376,12 @@ void CNextEvent (XEvent * xevent, CEvent * cwevent)
 		}
 		return;
 	    }
-#if 0
 	    if (xevent->xclient.data.l[0] == ATOM_WM_TAKE_FOCUS) {
-		? ? ? ?
+		hide_toolhint ();
+		toolhint_window = 0;
+		process_external_focus (win, type);
+		return;
 	    }
-#endif
 	}
 	break;
     }
