@@ -35,6 +35,7 @@ void CError (const char *fmt,...)
     va_start (s, fmt);
     str = vsprintf_alloc (catstrs (" ", fmt, " ", 0), s);
     CFatalErrorDialog (20, 20, str);
+    va_end (s);
     free (str);
 }
 
@@ -139,6 +140,7 @@ void set_cursor_position (Window win, int x, int y, int w, int h, int type, wcha
     }
 }
 
+int option_never_raise_wm_windows = 0;
 int option_xor_cursor = 0;
 int option_flashing_cursor = 1;
 unsigned long option_cursor_color;
@@ -470,7 +472,7 @@ CWidget *CSetupWidget (const char *identifier, Window parent, int x, int y,
     return (*w);
 }
 
-extern Atom ATOM_WM_PROTOCOLS, ATOM_WM_DELETE_WINDOW, ATOM_WM_NAME, ATOM_WM_NORMAL_HINTS;
+extern Atom ATOM_WM_PROTOCOLS, ATOM_WM_DELETE_WINDOW, ATOM_WM_TAKE_FOCUS, ATOM_WM_NAME, ATOM_WM_NORMAL_HINTS;
 
 void CSetWindowSizeHints (CWidget * wdt, int min_w, int min_h, int max_w, int max_h)
 {
@@ -585,8 +587,18 @@ Window CDrawHeadedDialog (const char *identifier, Window parent, int x, int y, c
 	wdt->label = (char *) strdup (label);
 	XSetIconName (CDisplay, win, wdt->label);
 	XStoreName (CDisplay, win, wdt->label);
-	XChangeProperty (CDisplay, win, ATOM_WM_PROTOCOLS, XA_ATOM, 32,
-	   PropModeReplace, (unsigned char *) &ATOM_WM_DELETE_WINDOW, 1);
+	{
+	    Atom a[2];
+	    a[0] = ATOM_WM_DELETE_WINDOW;
+#if 0
+	    a[1] = ATOM_WM_TAKE_FOCUS;
+	    XChangeProperty (CDisplay, win, ATOM_WM_PROTOCOLS, XA_ATOM, 32,
+		PropModeReplace, (unsigned char *) a, 2);
+#else
+	    XChangeProperty (CDisplay, win, ATOM_WM_PROTOCOLS, XA_ATOM, 32,
+		PropModeReplace, (unsigned char *) a, 1);
+#endif
+	}
 	reset_hint_pos (WIDGET_SPACING + 2, WIDGET_SPACING + 2);
 	wdt->position |= WINDOW_UNMOVEABLE;
 	wdt->options |= WINDOW_NO_BORDER;
@@ -596,7 +608,7 @@ Window CDrawHeadedDialog (const char *identifier, Window parent, int x, int y, c
 	win = CDrawDialog (identifier, parent, x, y);
 	(CDrawText (catstrs (identifier, ".header", 0), win, WIDGET_SPACING, WIDGET_SPACING + 2, label))->position |= POSITION_CENTRE;
 	CGetHintPos (&x, &y);
-#ifndef NEXT_LOOK_X
+#ifndef NEXT_LOOK
 	(CDrawBar (win, WIDGET_SPACING, y, 10))->position |= POSITION_FILL;
 	CGetHintPos (&x, &y);
 #endif
@@ -640,14 +652,17 @@ void CRaiseWMWindow (char *ident)
 {
     Window wm_win;
     CWidget *w;
+    XWindowChanges c;
+    XEvent ev;
 
     w = CIdent (ident);
     if (!w)
 	return;
-    wm_win = CGetWMWindow (w->winid);
+    wm_win = CGetWMWindow (w->mainid);
     if (!wm_win)
 	return;
-    XRaiseWindow (CDisplay, wm_win);
+    c.stack_mode = Above;
+    XConfigureWindow (CDisplay, wm_win, CWStackMode, &c);
     XFlush (CDisplay);
 }
 
@@ -731,7 +746,7 @@ CWidget *CDrawButton (const char *identifier, Window parent, int x, int y,
 	width = w + 4 + BUTTON_RELIEF * 2;
     if (height == AUTO_HEIGHT) {
 	height = h + 4 + BUTTON_RELIEF * 2;
-#ifdef NEXT_LOOK_X
+#ifdef NEXT_LOOK
 	height++ ;
 #endif	
     }	
@@ -1135,22 +1150,9 @@ void render_bar (CWidget * wdt)
     (*look->render_bar) (wdt);
 }
 
-#if 0
-
-#ifdef NEXT_LOOK_X
-#define FB (TEXT_RELIEF)
-#else
-#define FB (TEXT_RELIEF + 1)
-#endif
-#define FS (TEXT_RELIEF + 1)
-
-#else
-
 #define FB (TEXT_RELIEF + 1)
 #define FS (TEXT_RELIEF + 1)
 
-#endif
-
 /* this is a zero flicker routine */
 void render_status (CWidget * wdt, int expose)
 {
@@ -1208,18 +1210,8 @@ void render_status (CWidget * wdt, int expose)
 		XClearArea (CDisplay, win, x, TEXT_RELIEF + 1, x + FS, FONT_PIX_PER_LINE, 0);
 		if (x - x1 + FB + FB - 2 > 0) {
 		    render_bevel (win, x1 - FB, 0, x + FB - 1, h - 1, 1, 1);
-#if 0
-#ifdef NEXT_LOOK_X
-		    XClearArea (CDisplay, win, x1 - FB + 2, 2, x - x1 + FB + FB - 3, TEXT_RELIEF, 0);
-		    XClearArea (CDisplay, win, x1 - FB + 2, h - TEXT_RELIEF - 1, x - x1 + FB + FB - 3, TEXT_RELIEF, 0);
-#else
-		    XClearArea (CDisplay, win, x1 - FB + 1, 1, x - x1 + FB + FB - 2, TEXT_RELIEF, 0);
+		    XClearArea (CDisplay, win, x1 - FB + 1, 1, x - x1 + FB + FB - 2, TEXT_RELIEF + 1, 0);
 		    XClearArea (CDisplay, win, x1 - FB + 1, h - TEXT_RELIEF - 1, x - x1 + FB + FB - 2, TEXT_RELIEF, 0);
-#endif
-#else
-		    XClearArea (CDisplay, win, x1 - FB + 1, 1, x - x1 + FB + FB - 2, TEXT_RELIEF, 0);
-		    XClearArea (CDisplay, win, x1 - FB + 1, h - TEXT_RELIEF - 1, x - x1 + FB + FB - 2, TEXT_RELIEF, 0);
-#endif
 		}
 		x1 = x;
 		x += FS;
