@@ -420,25 +420,25 @@ XEvent *CRawkeyQuery (Window in, int x, int y, const char *heading, const char *
 
     CBackupState (&s);
     CDisable ("*");
-    win = CDrawHeadedDialog ("_inputdialog", in, x, y, heading);
+    win = CDrawHeadedDialog ("_rawkeydlg", in, x, y, heading);
     CGetHintPos (&x, &y);
-    CDrawText ("_inputdialog.text", win, x, y, "%s", str);
+    CDrawText ("_rawkeydlg.text", win, x, y, "%s", str);
     CGetHintPos (&x, 0);
     free (str);
-    CDrawTextInput ("_inputdialog.input", win, x, y, (FONT_MEAN_WIDTH) * 6, AUTO_HEIGHT, 256, "");
+    CDrawTextInput ("_rawkeydlg.input", win, x, y, (FONT_MEAN_WIDTH) * 6, AUTO_HEIGHT, 256, "");
     CGetHintPos (0, &y);
-    ((*look->draw_cross_cancel_button) ("_inputdialog.crosshere", win, -50, y))->position = POSITION_CENTRE;
-    CCentre ("_inputdialog.crosshere");
-    CSetSizeHintPos ("_inputdialog");
-    CMapDialog ("_inputdialog");
-    CFocus (CIdent ("_inputdialog.input"));
-    CIdent ("_inputdialog")->position = WINDOW_ALWAYS_RAISED;
+    ((*look->draw_cross_cancel_button) ("_rawkeydlg.crosshere", win, -50, y))->position = POSITION_CENTRE;
+    CCentre ("_rawkeydlg.crosshere");
+    CSetSizeHintPos ("_rawkeydlg");
+    CMapDialog ("_rawkeydlg");
+    CFocus (CIdent ("_rawkeydlg.input"));
+    CIdent ("_rawkeydlg")->position = WINDOW_ALWAYS_RAISED;
 /* handler : */
     do {
 	CNextEvent (&xevent, &cwevent);
-	if (!CIdent ("_inputdialog"))
+	if (!CIdent ("_rawkeydlg"))
 	    break;
-	if (cwevent.command == CK_Cancel || !strcmp (cwevent.ident, "_inputdialog.crosshere"))
+	if (cwevent.command == CK_Cancel || !strcmp (cwevent.ident, "_rawkeydlg.crosshere"))
 	    break;
 	if (xevent.type == KeyPress) {
 	    KeySym k;
@@ -448,7 +448,7 @@ XEvent *CRawkeyQuery (Window in, int x, int y, const char *heading, const char *
 	}
     } while (!p);
 
-    CDestroyWidget ("_inputdialog");
+    CDestroyWidget ("_rawkeydlg");
     CRestoreState (&s);
     return p;
 }
