@@ -129,6 +129,7 @@ char *edit_get_buffer_as_text (WEdit * e)
 /* returns 1 on error */
 /* loads file OR text into buffers. Only one must be none-NULL. */
 /* cursor set to start of file */
+/* FIXME: implement proper error handling on failed reads */
 int init_dynamic_edit_buffers (WEdit * edit, const char *filename, const char *text)
 {
     long buf;
@@ -152,7 +153,7 @@ int init_dynamic_edit_buffers (WEdit * edit, const char *filename, const char *t
     edit->buffers2[buf2] = CMalloc (EDIT_BUF_SIZE);
 
     if (filename) {
-	read (file, (char *) edit->buffers2[buf2] + EDIT_BUF_SIZE - (edit->curs2 & M_EDIT_BUF_SIZE), edit->curs2 & M_EDIT_BUF_SIZE);
+	readall (file, (char *) edit->buffers2[buf2] + EDIT_BUF_SIZE - (edit->curs2 & M_EDIT_BUF_SIZE), edit->curs2 & M_EDIT_BUF_SIZE);
     } else {
 	memcpy (edit->buffers2[buf2] + EDIT_BUF_SIZE - (edit->curs2 & M_EDIT_BUF_SIZE), text, edit->curs2 & M_EDIT_BUF_SIZE);
 	text += edit->curs2 & M_EDIT_BUF_SIZE;
@@ -161,7 +162,7 @@ int init_dynamic_edit_buffers (WEdit * edit, const char *filename, const char *t
     for (buf = buf2 - 1; buf >= 0; buf--) {
 	edit->buffers2[buf] = CMalloc (EDIT_BUF_SIZE);
 	if (filename) {
-	    read (file, (char *) edit->buffers2[buf], EDIT_BUF_SIZE);
+	    readall (file, (char *) edit->buffers2[buf], EDIT_BUF_SIZE);
 	} else {
 	    memcpy (edit->buffers2[buf], text, EDIT_BUF_SIZE);
 	    text += EDIT_BUF_SIZE;
@@ -708,7 +709,7 @@ void edit_push_action (WEdit * edit, long c,...)
 	va_end (ap);
     } else
 #endif				/* ! FAST_MOVE_CURSOR */
-    if (spm1 != edit->stack_bottom && ((sp - 2) & edit->stack_size_mask) != edit->stack_bottom) {
+    if (sp != edit->stack_bottom && spm1 != edit->stack_bottom && ((sp - 2) & edit->stack_size_mask) != edit->stack_bottom) {
 	int d;
 	if (edit->undo_stack[spm1] < 0) {
 	    d = edit->undo_stack[(sp - 2) & edit->stack_size_mask];
