@@ -952,8 +952,12 @@ void edit_insert_column_of_text (WEdit * edit, unsigned char *data, int size, in
 		}
 	    }
 	    for (p = edit->curs1;; p++) {
-		if (p == edit->last_byte)
+		if (p == edit->last_byte) {
+		    edit_cursor_move (edit, edit->last_byte - edit->curs1);
 		    edit_insert_ahead (edit, '\n');
+		    p++;
+		    break;
+		}
 		if (edit_get_byte (edit, p) == '\n') {
 		    p++;
 		    break;
@@ -2829,7 +2833,7 @@ int edit_printf (WEdit * e, const char *fmt,...)
     va_list pa;
     char s[1024];
     va_start (pa, fmt);
-    sprintf (s, fmt, pa);
+    vsprintf (s, fmt, pa);
     i = edit_print_string (e, s);
     va_end (pa);
     return i;
