@@ -143,12 +143,14 @@ void edit_status (WEdit *edit)
 
 void edit_status (WEdit * edit)
 {
+    static int name_trunc_len = 16;
+    int name_trunc_len_inc = 0;
     long start_mark, end_mark;
     CWidget *wdt;
     mode_t m;
     char *p;
     char id[33];
-    char s[256];
+    char s[4096];
     char b[64];
     if (eval_marks (edit, &start_mark, &end_mark))
 	end_mark = start_mark = 0;
@@ -164,8 +166,40 @@ void edit_status (WEdit * edit)
     } else {
 	sprintf (b, "\022EOF\033");
     }
-    sprintf (s, "\034%c%s\033\035  \034-%c%c%c%c%c%c%c%c%c\035  \034%s%s%s%c\035  \034\030%02ld\033\035  \034%-4ld+%2ld=\030%4ld\033/%3ld\035  \034*%-5ld/%5ldb=%s\035%c \034\001%ld\033\035",
-	     *p ? '\033' : '\003', *p ? (char *) name_trunc (p, max (edit->num_widget_lines / 3, 16)) : _ ("<unnamed>"),
+    CPushFont ("widget", 0);
+    for (;;) {
+	int status_text_width;
+	sprintf (s,
+		 "%s  -rwxrwxrwx  MMMM  %02ld  %-4ld+%2ld=%4ld/%3ld  *%-5ld/%5ldb=%s%c %ld",
+		 *p ? (char *) name_trunc (p, name_trunc_len) : _("<unnamed>"),
+		 edit->curs_col / FONT_MEAN_WIDTH, edit->start_line + 1, edit->curs_row,
+		 edit->curs_line + 1, edit->total_lines + 1, edit->curs1, edit->last_byte, b,
+		 end_mark - start_mark && !column_highlighting ? ' ' : '\0', end_mark - start_mark);
+	status_text_width = CImageTextWidth (s, strlen (s));
+	if (name_trunc_len_inc >= 0)
+	    if (status_text_width < CWidthOf (edit->widget) - 13) {
+		if (name_trunc_len < strlen (p)) {
+		    name_trunc_len++;
+		    name_trunc_len_inc = 1;
+		    continue;
+		}
+	    }
+	if (name_trunc_len_inc <= 0)
+	    if (status_text_width > CWidthOf (edit->widget) - 13) {
+		if (name_trunc_len > 16) {
+		    name_trunc_len--;
+		    name_trunc_len_inc = -1;
+		    continue;
+		}
+	    }
+	if (name_trunc_len_inc > 0)
+	    name_trunc_len--;
+	break;
+    }
+    CPopFont ();
+    sprintf (s,
+	     "\034%c%s\033\035  \034-%c%c%c%c%c%c%c%c%c\035  \034%s%s%s%c\035  \034\014%02ld\033\035  \034%-4ld+%2ld=\014%4ld\033/%3ld\035  \034*%-5ld/%5ldb=%s\035%c \034\001%ld\033\035",
+	     *p ? '\033' : '\003', *p ? (char *) name_trunc (p, name_trunc_len) : _("<unnamed>"),
 	     m & S_IRUSR ? 'r' : '-',
 	     m & S_IWUSR ? 'w' : '-',
 	     m & S_IXUSR ? 'x' : '-',
@@ -175,14 +209,14 @@ void edit_status (WEdit * edit)
 	     m & S_IROTH ? 'r' : '-',
 	     m & S_IWOTH ? 'w' : '-',
 	     m & S_IXOTH ? 'x' : '-',
-	     end_mark - start_mark || (edit->mark2 == -1 && !edit->highlight) ? (column_highlighting ? "\032C\033" : "\001B\033") : "-",
+	     end_mark - start_mark || (edit->mark2 == -1
+				       && !edit->highlight) ? (column_highlighting ? "\032C\033" :
+							       "\001B\033") : "-",
 	     edit->modified ? "\012M\033" : "-", edit->macro_i < 0 ? "-" : "\023R\033",
-	     edit->overwrite == 0 ? '-' : 'O',
-	     edit->curs_col / FONT_MEAN_WIDTH, edit->start_line + 1, edit->curs_row,
-	     edit->curs_line + 1, edit->total_lines + 1, edit->curs1,
-	     edit->last_byte, b,
-	     end_mark - start_mark && !column_highlighting ? ' ' : '\0',
-	     end_mark - start_mark);
+	     edit->overwrite == 0 ? '-' : 'O', edit->curs_col / FONT_MEAN_WIDTH,
+	     edit->start_line + 1, edit->curs_row, edit->curs_line + 1, edit->total_lines + 1,
+	     edit->curs1, edit->last_byte, b, end_mark - start_mark
+	     && !column_highlighting ? ' ' : '\0', end_mark - start_mark);
     strcpy (id, CIdentOf (edit->widget));
     strcat (id, ".text");
     wdt = CIdent (id);
