@@ -106,7 +106,7 @@ static void shell_output_read_callback (int fd, fd_set * reading, fd_set * writi
 {
     WEdit *edit;
     unsigned char s[SHELL_OUTPUT_BUF_SIZE];
-    int i, n, move_mark;
+    int i, n, move_mark = 0;
     long start_mark, end_mark;
     edit = (WEdit *) data;
     if (!eval_marks (edit, &start_mark, &end_mark))
@@ -1058,7 +1058,7 @@ int eh_editor (CWidget * w, XEvent * xevent, CEvent * cwevent)
 	    column_highlighting = 0;
 	}
     case MotionNotify:
-	if (!xevent->xmotion.state && xevent->type == MotionNotify)
+	if (xevent->type == MotionNotify && !(xevent->xmotion.state & Button12345Mask))
 	    return 0;
 	resolve_button (xevent, cwevent);
 	if ((cwevent->button == Button4 || cwevent->button == Button5)
