@@ -135,9 +135,9 @@ static int *get_field_sizes (void *data, int *num_lines, int *max_width,
     for (i = 0; i < max_num_fields; i++)
 	*max_width += tab[i];
 
-    result = CMalloc (max_num_fields * sizeof (int));
+    result = CMalloc ((max_num_fields + 1) * sizeof (int));
     memcpy (result, tab, max_num_fields * sizeof (int));
-    tab[max_num_fields] = 0;
+    result[max_num_fields] = 0;
     return result;
 }
 
@@ -678,10 +678,10 @@ static void convert_text_fielded_textbox (CWidget * w, long q, cache_type *line,
 	k = 0;
 
     p = line;
-    p->c.ch = p->style = 0;
+    p->c.ch = p->_style = 0;
     for (;;) {
 	c = text[k];
-	p[1].style = p[1].c.ch = 0;
+	p[1]._style = p[1].c.ch = 0;
 	p->c.fg = p->c.bg = 0xFF;	/* default background colors */
 	if (highlight_this_line)
 	    p->c.style |= MOD_HIGHLIGHTED;
@@ -737,7 +737,7 @@ static void convert_text_fielded_textbox (CWidget * w, long q, cache_type *line,
 	q++;
 	k++;
     }
-    p->c.ch = p->style = 0;
+    p->c.ch = p->_style = 0;
 }
 
 
@@ -809,6 +809,8 @@ void render_fielded_textbox (CWidget * w, int redrawall)
     x = 0;
     CSetColor (COLOR_FLAT);
     for (i = 0;; i++) {
+	if (!w->tab[i])
+	    break;
 	x += w->tab[i];
 	if (x >= w->column)
 	    break;
@@ -818,6 +820,8 @@ void render_fielded_textbox (CWidget * w, int redrawall)
 	x = 0;
         CSetColor (color_palette (option_text_bg_normal));
 	for (i = 0;; i++) {
+	    if (!w->tab[i])
+		break;
 	    x += w->tab[i];
 	    if (x >= w->column)
 		break;
