@@ -123,8 +123,11 @@ char *init_bg_color = DEFAULT_BG_COLOR;
 char *init_fg_color_red = DEFAULT_WIDGET_COLOR_R;
 char *init_fg_color_green = DEFAULT_WIDGET_COLOR_G;
 char *init_fg_color_blue = DEFAULT_WIDGET_COLOR_B;
+#ifndef NEXT_LOOK
 char *init_look = "gtk";
-
+#else
+char *init_look = "next";
+#endif
 
 Atom ATOM_WM_PROTOCOLS, ATOM_WM_DELETE_WINDOW;
 Atom ATOM_WM_NAME, ATOM_WM_NORMAL_HINTS, ATOM_WM_TAKE_FOCUS;
@@ -838,10 +841,12 @@ static struct itimerval alarm_off =
    a CSendEvent.
  */
 int block_push_event = 0;
+int got_alarm = 0;
 
-static RETSIGTYPE alarmhandler (int x)
+void _alarmhandler (void)
 {
     static int count = ALRM_PER_SECOND;
+    got_alarm = 0;
     if (count) {
 	count--;
 	if (CQueueSize () < 16 && !block_push_event) {
@@ -849,12 +854,18 @@ static RETSIGTYPE alarmhandler (int x)
 	}
     } else {
 	xevent.type = AlarmEvent;
-	if (CQueueSize () < 128 && !block_push_event) {		/* say */
+	if (CQueueSize () < 128 && !block_push_event) {	/* say */
 	    CSendEvent (&xevent);
 	}
 	xevent.type = TickEvent;
 	count = ALRM_PER_SECOND / cursor_blink_rate;
     }
+}
+
+static RETSIGTYPE alarmhandler (int x)
+{
+    if (!got_alarm)
+	got_alarm = 1;
     signal (SIGALRM, alarmhandler);
     setitimer (ITIMER_REAL, &alarm_every, NULL);
 #if (RETSIGTYPE==void)
@@ -869,8 +880,12 @@ static RETSIGTYPE alarmhandler (int x)
 static struct {
     pid_t pid;
     int status;
+    unsigned long count;
 } children_exitted[CHILD_EXITED_MAX];
 
+static long child_exit_counter = 1;
+static int num_children_exitted = 0;
+
 #if (RETSIGTYPE==void)
 #define handler_return return
 #else
@@ -878,24 +893,44 @@ static struct {
 #endif
 
 static RETSIGTYPE childhandler (int x)
+{
+    num_children_exitted++;
+    signal (SIGCHLD, childhandler);
+    handler_return;
+}
+
+void  childhandler_ (void)
 {
     pid_t p, save_errno = errno;
-    int i, status, j;
-    for (j = 0; j < 2; j++) {
+    int i, status, j, n;
+    if (!num_children_exitted)
+	return;
+    n = num_children_exitted + 1;
+    for (j = 0; j < n; j++) {
 	do {
 	    errno = 0;
 	} while ((-1 == (p = waitpid (-1, NULL, WNOHANG))) && (errno == EINTR));
-	if (p > 0)
-	    for (i = 0; i < CHILD_EXITED_MAX; i++)
+	if (num_children_exitted > 0)
+	    num_children_exitted--;
+	if (p > 0) {
+	    unsigned long minimum = (unsigned long) (-1);
+	    int i_min = 0;
+	    for (i = 0; i < CHILD_EXITED_MAX; i++) {
 		if (!children_exitted[i].pid) {
-		    children_exitted[i].pid = p;
-		    children_exitted[i].status = status;
+		    i_min = i;
 		    break;
 		}
+		if (children_exitted[i].count < minimum) {
+		    minimum = children_exitted[i].count;
+		    i_min = i;
+		}
+	    }
+	    children_exitted[i_min].pid = p;
+	    children_exitted[i_min].status = status;
+	    children_exitted[i_min].count = child_exit_counter++;
+	}
     }
     errno = save_errno;
-    signal (SIGCHLD, childhandler);
-    handler_return;
 }
 
 /* returns non-zero on child exit */
@@ -907,6 +942,7 @@ int CChildExitted (pid_t p, int *status)
 	    if (status)
 		*status = children_exitted[i].status;
 	    children_exitted[i].pid = 0;
+	    children_exitted[i].count = 0;
 	    return 1;
 	}
     return 0;
