@@ -423,7 +423,7 @@ void render_textinput (CWidget * wdt)
 	    wdt->firstcolumn--;
 	    f = 1;
 	    /*Unless of course we are at the beginning of the string */
-	    if (wdt->firstcolumn < 0) {
+	    if (wdt->firstcolumn <= 0) {
 		wdt->firstcolumn = 0;
 		f = 0;
 	    }
