@@ -484,7 +484,7 @@ static Window draw_file_browser (const char *identifier, Window parent, int x, i
 	*++p = '/';
 	*++p = '\0';
     }
-    (CDrawText (catstrs (identifier, ".dir", 0), win, x, y, resolved_path))->position |= POSITION_FILL;
+    (CDrawText (catstrs (identifier, ".dir", 0), win, x, y, "%s", resolved_path))->position |= POSITION_FILL;
     free (resolved_path);
     CGetHintPos (0, &y);
     reset_hint_pos (x, y);
@@ -794,7 +794,7 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 		    *++q = '/';
 		    *++q = '\0';
 		}
-		CRedrawText (catstrs (identifier, ".dir", 0), estr);
+		CRedrawText (catstrs (identifier, ".dir", 0), "%s", estr);
 		if (options & GETFILE_BROWSER)
 		    CAddToTextInputHistory (textinput->ident, estr);
 	    }
