@@ -35,7 +35,7 @@ static void float_error (char *file, int line)
     abort ();
 }
 
-#if !defined(__i386__) || !defined(__GNUC__) || defined(USE_OWN_POW)
+#if !defined(__i386__) || !defined(__GNUC__) || !defined(__linux__) || defined(USE_OWN_POW)
 
 /*
    Libc pow() using an FPU is timed to be
