@@ -508,11 +508,11 @@ void mouse_mark (XEvent * event, int double_click, struct mouse_funcs *funcs)
 	state = 0;
 	if (funcs->redraw)
 	    (*funcs->redraw) (data, click);
-    } else if (event->type == MotionNotify && state > 0 && win_press == (unsigned long) event->xbutton.window && event->xbutton.state) {
+    } else if (event->type == MotionNotify && state > 0 && win_press == (unsigned long) event->xmotion.window && (event->xmotion.state & Button12345Mask)) {
 	int x, y;
-	if (!event->xmotion.state)
+	if (!(event->xmotion.state & Button12345Mask))
 	    return;
-	(*funcs->xy) (event->xbutton.x, event->xbutton.y, &x, &y);
+	(*funcs->xy) (event->xmotion.x, event->xmotion.y, &x, &y);
 	if (x == x_last && y == y_last && state == 1)
 	    return;
 	click = (*funcs->cp) (data, x, y);
