@@ -34,6 +34,7 @@ int option_long_whitespace = 0;
 int cache_width = 0;
 int cache_height = 0;
 
+/* must be a multiple of 8 */
 #define MAX_LINE_LEN 1024
 
 
@@ -301,7 +302,7 @@ static inline cache_type get_style_fast (WEdit * edit, long q, wchar_t c)
 {
     cache_type s;
     unsigned int fg, bg;
-    s.c.ch = s.style = 0;
+    s.c.ch = s._style = 0;
     if (!(wc_isprint (c) || (option_international_characters && FONT_PER_CHAR(c))))
 	if (c != '\n' && c != '\t')
 	    s.c.style = MOD_ABNORMAL;
@@ -316,7 +317,7 @@ static inline cache_type get_style (WEdit * edit, long q, wchar_t c, long m1, lo
 {
     cache_type s;
     unsigned int fg, bg;
-    s.c.ch = s.style = 0;
+    s.c.ch = s._style = 0;
     if (q == edit->curs1)
 	s.c.style |= MOD_CURSOR;
     if (q >= m1 && q < m2) {
@@ -362,7 +363,7 @@ static void convert_text (WEdit * edit, long q, cache_type * p, int x, int x_max
 	    if (!the_end)
 		*p = get_style (edit, q, c, m1, m2, x);
 	    if (the_end)
-		p->c.ch = p->style = 0;
+		p->c.ch = p->_style = 0;
 	    book_mark_cycle = (book_mark_cycle + 1) % book_mark;
 	    p->c.fg = book_mark_colors[book_mark_cycle] << 8;
 	    p->c.bg = book_mark_colors[book_mark_cycle];
@@ -448,7 +449,7 @@ static void convert_text (WEdit * edit, long q, cache_type * p, int x, int x_max
 		break;
 	    case '\n':
 		(p++)->c.ch = ' ';
-		p->c.ch = p->style = 0;
+		p->c.ch = p->_style = 0;
 		if (x > edit->max_column)
 		    edit->max_column = x;
 		return;
@@ -530,7 +531,7 @@ static void convert_text (WEdit * edit, long q, cache_type * p, int x, int x_max
 		break;
 	    case '\n':
 		(p++)->c.ch = ' ';
-		p->c.ch = p->style = 0;
+		p->c.ch = p->_style = 0;
 		if (x > edit->max_column)
 		    edit->max_column = x;
 		return;
@@ -597,7 +598,7 @@ static void convert_text (WEdit * edit, long q, cache_type * p, int x, int x_max
     }
     if (x > edit->max_column)
 	edit->max_column = x;
-    p->c.ch = p->style = 0;
+    p->c.ch = p->_style = 0;
 }
 
 static void edit_set_cursor (Window win, int x, int y, int bg, int fg, int width, wchar_t t, int style)
@@ -771,9 +772,9 @@ static int draw_string (Window win, int x, int y, cache_type s, XChar2b *text, w
 #endif
 }
 
-#define STYLE_DIFF (cache->style != line->style || cache->c.ch != line->c.ch \
+#define STYLE_DIFF (cache->_style != line->_style || cache->c.ch != line->c.ch \
 	    || ((cache->c.style | line->c.style) & MOD_CURSOR) \
-	    || !(cache->c.ch | cache->style) || !(line->c.ch | line->style))
+	    || !(cache->c.ch | cache->_style) || !(line->c.ch | line->_style))
 
 int get_ignore_length (cache_type *cache, cache_type *line)
 {
@@ -788,14 +789,14 @@ int get_ignore_length (cache_type *cache, cache_type *line)
 static inline size_t lwstrnlen (const cache_type * s, size_t count)
 {
     const cache_type *sc;
-    for (sc = s; count-- && (sc->c.ch | sc->style) != 0; ++sc);
+    for (sc = s; count-- && (sc->c.ch | sc->_style) != 0; ++sc);
     return sc - s;
 }
 
 static inline size_t lwstrlen (const cache_type * s)
 {
     const cache_type *sc;
-    for (sc = s; (sc->c.ch | sc->style) != 0; ++sc);
+    for (sc = s; (sc->c.ch | sc->_style) != 0; ++sc);
     return sc - s;
 }
 
@@ -877,6 +878,7 @@ static void edit_realloc_cache_lines (int width, int height)
 	cache_width = max (width + 10, cache_width);
 	cache_height = max (height + 10, cache_height);
 	cache_lines = malloc (sizeof (struct cache_line) * cache_height);
+	memset (cache_lines, 0, sizeof (struct cache_line) * cache_height);
 	for (i = 0; i < cache_height; i++) {
 	    cache_lines[i].data = malloc (sizeof (cache_type) * (cache_width + 1));
 	    memset (cache_lines[i].data, 0, sizeof (cache_type) * (cache_width + 1));
@@ -894,10 +896,10 @@ static void reverse_text (cache_type * line)
 {
     int i, n;
     if (option_reverse_hebrew) {
-	while (line->c.ch | line->style) {
-	    while (!IS_HEBREW (line->c.ch) && (line->c.ch | line->style))
+	while (line->c.ch | line->_style) {
+	    while (!IS_HEBREW (line->c.ch) && (line->c.ch | line->_style))
 		line++;
-	    for (n = 0; (IS_HEBREW (line[n].c.ch) || (line[n].c.ch == ' ')) && (line[n].c.ch | line[n].style); n++);
+	    for (n = 0; (IS_HEBREW (line[n].c.ch) || (line[n].c.ch == ' ')) && (line[n].c.ch | line[n]._style); n++);
 	    while (n && !IS_HEBREW (line[n - 1].c.ch))
 		n--;
 	    n--;
@@ -957,6 +959,16 @@ void edit_draw_proportional (void *data,
 /* q contains the offset in the edit buffer */
 
 /* translate this line into printable characters with a style (=color) high byte */
+    for (i = 0; i < MAX_LINE_LEN; i += 8) {
+	line[i]._style = line[i].c.ch = 0;
+	line[i + 1]._style = line[i + 1].c.ch = 0;
+	line[i + 2]._style = line[i + 2].c.ch = 0;
+	line[i + 3]._style = line[i + 3].c.ch = 0;
+	line[i + 4]._style = line[i + 4].c.ch = 0;
+	line[i + 5]._style = line[i + 5].c.ch = 0;
+	line[i + 6]._style = line[i + 6].c.ch = 0;
+	line[i + 7]._style = line[i + 7].c.ch = 0;
+    }
     (*converttext) (data, q, line, x0, x_max - scroll_right - EDIT_TEXT_HORIZONTAL_OFFSET, row);
     reverse_text (line);
 
@@ -974,7 +986,7 @@ void edit_draw_proportional (void *data,
     }
     p = line;
     j = 0;
-    while (p->c.ch | p->style) {
+    while (p->c.ch | p->_style) {
 	if (p->c.style & MOD_PIXMAP) {
 #ifdef STILL_TO_BE_SUPPORTED
 	    x += edit_insert_pixmap (win, x, y, p->c.ch);
@@ -1008,7 +1020,7 @@ void edit_draw_proportional (void *data,
 		j++;
 		if (j == ignore_text || j == ignore_trailer)
 		    break;
-	    } while (i < 128 && p->c.ch && style.style == p->style && p->c.ch != '\t');
+	    } while (i < 128 && p->c.ch && style._style == p->_style && p->c.ch != '\t');
 
 	    if (j > ignore_text && j < ignore_trailer + 1) {
 		x = draw_string (win, x, y, style, text, textwc, i);
@@ -1030,7 +1042,7 @@ void edit_draw_proportional (void *data,
 	 (min (j, cache_width) - ignore_text) * sizeof (cache_type));
 
     cache_lines[row].data[min (j, cache_width)].c.ch = 0;
-    cache_lines[row].data[min (j, cache_width)].style = 0;
+    cache_lines[row].data[min (j, cache_width)]._style = 0;
 
     cache_lines[row].x0 = x0;
     cache_lines[row].x1 = x;
@@ -1139,11 +1151,11 @@ void convert_text2 (CWidget * w, long q, cache_type * line, int x, int x_max, in
     m2 = max (w->mark1, w->mark2);
 
     p = line;
-    p->c.ch = p->style = 0;
+    p->c.ch = p->_style = 0;
     for (;;) {
 	d = c;
 	c = (unsigned char) w->text[q];
-	p[1].c.ch = p[1].style = 0;
+	p[1].c.ch = p[1]._style = 0;
 	p->c.fg = p->c.bg = 0xFF;	/* default background colors */
 	if (highlight_this_line)
 	    p->c.style |= MOD_HIGHLIGHTED;
@@ -1168,7 +1180,7 @@ void convert_text2 (CWidget * w, long q, cache_type * line, int x, int x_max, in
 		while (i > 0) {
 		    i -= FONT_PER_CHAR (' ');
 		    (p++)->c.ch = s.c.ch | ' ';
-		    p->c.ch = p->style = 0;
+		    p->c.ch = p->_style = 0;
 		}
 	    } else {
 		(p++)->c.ch |= '\t';
@@ -1200,7 +1212,7 @@ void convert_text2 (CWidget * w, long q, cache_type * line, int x, int x_max, in
 	    break;
 	q++;
     }
-    p->c.ch = p->style = 0;
+    p->c.ch = p->_style = 0;
 }
 
 
