@@ -27,6 +27,7 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#include <errno.h>
 #include "stringtools.h"
 #include "regex.h"
 #include "time.h"
@@ -516,6 +517,14 @@ char *vsprintf_alloc (const char *fmt, va_list ap)
 {
     char *s;
     size_t l;
+
+#ifdef __va_copy
+    va_list va_save;
+    __va_copy (va_save, ap);
+#else
+#define va_save ap
+#endif /* defined __va_copy */
+
 #ifdef HAVE_MAD
     s = mad_alloc ((l = vfmtlen (fmt, ap)) + 1, file, line);
 #else
@@ -525,7 +534,7 @@ char *vsprintf_alloc (const char *fmt, va_list ap)
 /* NLS ? */
 	fprintf (stderr, "cooledit:%s:%d: malloc return zero\n", __FILE__, __LINE__);
     s[l] = 0;
-    vsprintf (s, fmt, ap);
+    vsprintf (s, fmt, va_save);
     if (s[l]
 #ifdef DEBUG_VFMTLEN
      || strlen (s) != l
@@ -548,3 +557,25 @@ char *sprintf_alloc (const char *fmt,...)
     return s;
 }
 
+int readall (int fd, char *buf, int len)
+{
+    int count;
+    int total = 0;
+    if (len <= 0)
+	return 0;
+    for (;;) {
+	count = read (fd, buf, len);
+	if (count == -1) {
+	    if (errno == EINTR)
+		continue;
+	    return -1;
+	}
+	buf += count;
+	len -= count;
+	total += count;
+	if (len <= 0)
+	    break;
+    }
+    return total;
+}
+
