@@ -192,7 +192,7 @@ static long compare_word_to_right (WEdit * edit, long i, char *text, char *whole
             }
 #endif
 	default:
-	    if (*p != edit_get_byte (edit, i))
+	    if (*p != (unsigned char) edit_get_byte (edit, i))
 		return -1;
 	}
     }
@@ -320,8 +320,10 @@ static inline struct syntax_rule apply_rules_going_right (WEdit * edit, long i,
 			_rule.border = RULE_ON_LEFT_BORDER;
 			_rule._context = count;
 			if (!r->between_delimiters)
-			    if (!_rule.keyword)
+			    if (!_rule.keyword) {
 				_rule.context = count;
+				contextchanged = 1;
+			    }
 			break;
 		    }
 		}
@@ -1202,7 +1204,7 @@ void edit_free_syntax_rules (WEdit * edit)
     syntax_free (edit->rules);
 }
 
-#define CURRENT_SYNTAX_RULES_VERSION "67"
+#define CURRENT_SYNTAX_RULES_VERSION "68"
 
 char *syntax_text[] = {
 "# syntax rules version " CURRENT_SYNTAX_RULES_VERSION,
@@ -1309,6 +1311,18 @@ char *syntax_text[] = {
 "file ..\\*\\\\.(lua|LUA)$ LUA\\sSource",
 "include lua.syntax",
 "",
+"file ..\\*\\\\.(p|P)$ Prolog\\sProgram",
+"include prolog.syntax",
+"",
+"file ..\\*\\\\.(xml|XML)$ XML\\sFile <?xml",
+"include xml.syntax",
+"",
+"file ..\\*\\\\.(css|CSS)$ CSS\\sFile <?xml",
+"include css.syntax",
+"",
+"file ..\\*\\\\.(sql|SQL)$ SQL\\sFile",
+"include sql.syntax",
+"",
 "file Don_t_match_me Mail\\sfolder ^From\\s",
 "include mail.syntax",
 "",
