@@ -113,9 +113,6 @@ void init_xlocale (void)
     } else if (!current_font->font_set) {
 	xim_print_error ("Font set not loaded - cannot create input method.");
     } else {
-#ifdef GREEK_SUPPORT
-	greek_init ();
-#endif
 	if (option_use_xim)
 	    XRegisterIMInstantiateCallback (CDisplay, NULL, NULL, NULL, IMInstantiateCallback, NULL);
     }
@@ -163,25 +160,22 @@ static void IMSendSpot (Window window)
 
 KeySym key_sym_xlat (XEvent * ev, char *x_lat)
 {
+    static KeySym r;
     static int len = 0;
     static KeySym keysym = 0;
     static XComposeStatus compose =
     {NULL, 0};
     static unsigned char kbuf[512] = "";
-    static Time time = 0;
     static int valid_keysym = 1;
     Status status_return = 0;
-#ifdef GREEK_SUPPORT
-    static short greek_mode = 0;
-#endif
     if (x_lat)
 	*x_lat = '\0';
     if (ev->type != KeyPress && ev->type != KeyRelease)
 	return 0;
 /* we mustn't call this twice with the same event */
-    if (time == ev->xkey.time)
+    if (ev->xkey.x_root == 31234)
 	goto no_repeat_call;
-    time = ev->xkey.time;
+    ev->xkey.x_root = 31234;
     keysym = 0;
     len = 0;
     if (ev->type == KeyRelease) {
@@ -206,25 +200,7 @@ KeySym key_sym_xlat (XEvent * ev, char *x_lat)
 			       sizeof (kbuf), &keysym, &status_return);
 	valid_keysym = ((status_return == XLookupKeySym)
 			|| (status_return == XLookupBoth));
-	if (valid_keysym) {
-#ifdef GREEK_SUPPORT
-	    if (keysym == XK_Mode_switch) {
-		greek_mode = !greek_mode;
-		if (greek_mode) {
-		    xterm_seq (XTerm_title,
-		      (greek_getmode () == GREEK_ELOT928 ? "[Greek: iso]"
-		       : "[Greek: ibm]"));
-		    greek_reset ();
-		} else
-		    xterm_seq (XTerm_title, APL_NAME "-" VERSION);
-		return;
-	    }
-#endif
-	}
     } else {
-#if 0
-      lookup_string:
-#endif
 	keysym = 0;
 	len = XLookupString (&ev->xkey, (char *) kbuf, sizeof (kbuf), &keysym, &compose);
 	if (!len && (keysym >= 0x0100) && (keysym < 0x0800)) {
@@ -241,7 +217,8 @@ KeySym key_sym_xlat (XEvent * ev, char *x_lat)
 	    x_lat[len] = '\0';
 	}
     }
-    return valid_keysym ? keysym : 0;
+    r = ((keysym >= 0x0100) && (keysym < 0x0800)) ? (valid_keysym ? kbuf[0] : 0) : (valid_keysym ? keysym : 0);
+    return r;
 }
 
 
@@ -564,7 +541,6 @@ KeySym key_sym_xlat (XEvent * ev, char *x_lat)
     static XComposeStatus compose =
     {NULL, 0};
     static unsigned char kbuf[512] = "";
-    static Time time = 0;
     static int valid_keysym = 1;
     Status status_return = 0;
     if (x_lat)
@@ -572,9 +548,9 @@ KeySym key_sym_xlat (XEvent * ev, char *x_lat)
     if (ev->type != KeyPress && ev->type != KeyRelease)
 	return 0;
 /* we mustn't call this twice with the same event */
-    if (time == ev->xkey.time)
+    if (ev->xkey.x_root == 31234)
 	goto no_repeat_call;
-    time = ev->xkey.time;
+    ev->xkey.x_root = 31234;
     keysym = 0;
     len = 0;
     if (ev->type == KeyRelease) {
